<!DOCTYPE html>
<html>
  <head>
    <meta charset="UTF-8">
    <meta name="format-detection" content="telephone=no" />
    <meta name="viewport" content="user-scalable=no, initial-scale=1, maximum-scale=1, minimum-scale=1, width=device-width, height=device-height, target-densitydpi=device-dpi" />
    <title>jukePi</title>
    <link rel="shortcut icon" href="favicon.ico">
    <link rel="stylesheet" type="text/css" href="css/app.css?{{ jukepi_version }}">
  </head>
  <body>
    <script src="js/bundle.js?{{ jukepi_version }}"></script>
    <script src="js/app.js?{{ jukepi_version }}"></script>
    {% for custom_script in custom_scripts %}<script src="{{ custom_script }}"></script>
    {% end %}<script>jukePi({% raw js_settings %}{% if jukepi_callback %}, {{ jukepi_callback }}{% end %});</script>
  </body>
</html>
